import * as React from 'react';
import { IssueArticleOpenEventDataType, ReportData, SyncReportOpenedEventDataType, WorkflowMapping } from './report-data-typings';
import './Report.scss';
declare type Levels = 'Error' | 'Warning' | 'Info' | 'Fatal' | 'Critical';
export declare type Issues = 'Error' | 'Warning' | 'Info' | 'All';
export declare type Tables = 'files' | 'problems' | 'categories' | 'issueId';
declare type AuditInfo = Partial<{
    issueid: string;
    level: Levels;
    category: string;
    message: string;
    type: string;
    fileName: string;
    path: string;
    fileId: string;
    dataSource: string;
    fileExists: boolean;
    bimFileExists: boolean;
}>;
export declare type TotalIssueCount = {
    issueCount?: number;
    linkedIssueCount?: number;
};
export declare const ReportContext: React.Context<{
    reportData: ReportData;
    workflowMapping?: WorkflowMapping | undefined;
    currentTable: Tables;
    setCurrentTable: (table: Tables | ((prev: Tables) => Tables)) => void;
    currentAuditInfo?: Partial<{
        issueid: string;
        level: Levels;
        category: string;
        message: string;
        type: string;
        fileName: string;
        path: string;
        fileId: string;
        dataSource: string;
        fileExists: boolean;
        bimFileExists: boolean;
    }> | undefined;
    setCurrentAuditInfo: (auditInfo?: AuditInfo) => void;
    focusedIssue: Issues;
    setFocusedIssue: (issue: Issues) => void;
    focusedWorkflows: string[];
    setFocusedWorkflows: (issues: string[] | ((issues: string[]) => string[])) => void;
    activeRow: string;
    setActiveRow: React.Dispatch<React.SetStateAction<string>>;
    onIssueArticleOpened?: ((issueId: string) => void) | undefined;
} | undefined>;
/**
 * `Report` is the root component where the report data should be passed.
 *
 * When `children` are not specified, a default sensible layout is shown.
 *
 * For extra flexibility (e.g. custom layouts, localization), the individual components can be passed as `children`
 * along with any additional elements. The report data is made available to child components through context so that
 * it does not need to be passed individually.
 *
 * @example
 * <Report data={reportData} workflowMapping={workflowMapping}/>
 *
 * @example
 * <Report data={reportData} workflowMapping={workflowMapping}>
 *   <div style={{ display: 'flex' }}>
 *    <ReportTitle />
 *    <ReportDebugIds />
 *   </div>
 *   <ReportTableSelect />
 *   <ReportInfoPanelWrapper>
 *       <ProblemsTable />
 *     <ReportInfoPanel />
 *   </ReportInfoPanelWrapper>
 * </Report>
 */
export declare const Report: ({ data, workflowMapping, children, className, applicationInsightConnectionString, applicationInsightInstrumentationKey, SyncReportOpenedEventProps, issueArticleOpenEventProps, }: {
    /** The report data should be compatible with the type definitions. */
    data: ReportData;
    applicationInsightConnectionString?: string | undefined;
    applicationInsightInstrumentationKey?: string | undefined;
    SyncReportOpenedEventProps?: SyncReportOpenedEventDataType | undefined;
    issueArticleOpenEventProps?: IssueArticleOpenEventDataType | undefined;
    workflowMapping?: WorkflowMapping | undefined;
    className?: string | undefined;
    children?: React.ReactNode;
}) => JSX.Element;
export default Report;
