export declare type AdditionalPropsType = {
    propertyName: string;
    value: unknown;
};
export declare type ReportData = {
    context?: ReportDataContext;
    sourceFilesInfo?: SourceFilesInfo;
    filerecords?: FileRecord[];
    elementRecords?: ElementRecord[];
    [k: string]: unknown;
    additionalPropsForUI?: AdditionalPropsType[];
};
export declare type Workflow = string;
export declare type Type = {
    [type: string]: Workflow[];
};
export declare enum ReportType {
    TransformationReport = "TransformationUserReport",
    SynchronizationDetailReport = "detailReport",
    SynchronizationSummaryReport = "summaryReport"
}
export declare type WorkflowMapping = {
    [category: string]: Type;
};
export declare type ElementRecord = {
    elementids?: string;
    reason?: string;
    repositorylinkId?: string;
    [k: string]: unknown;
    additionalPropsForUI?: AdditionalPropsType[];
};
export declare type SourceFilesInfo = {
    itemType?: string;
    dataSource?: string;
    path?: string;
    fileId?: string;
    fileName?: string;
    fileExists?: boolean;
    bimFileExists?: boolean;
    Files?: SourceFile[];
    [k: string]: unknown;
    additionalPropsForUI?: AdditionalPropsType[];
};
export declare type SourceFile = {
    fileId?: string;
    fileName?: string;
    path?: string;
    fileExists?: boolean;
    bimFileExists?: boolean;
    state?: string;
    iModelFileId?: string;
    failureReason?: string;
    [k: string]: unknown;
    additionalPropsForUI?: AdditionalPropsType[];
};
export declare type ReportDataContext = {
    reportType?: ReportType;
    operationType?: string;
    jobid?: string;
    contextid?: string;
    imodelid?: string;
    activityid?: string;
    briefcaseid?: string;
    timestamp?: string;
    [k: string]: unknown;
    additionalPropsForUI?: AdditionalPropsType[];
};
export declare type FileRecord = {
    auditrecords?: AuditRecord[];
    file?: {
        identifier?: string;
        path?: string;
        [k: string]: unknown;
        additionalPropsForUI?: AdditionalPropsType[];
    };
    [k: string]: unknown;
    additionalPropsForUI?: AdditionalPropsType[];
};
export declare type AuditRecord = {
    auditinfo?: AuditInfo;
    elementinfo?: ElementInfo;
    [k: string]: unknown;
    additionalPropsForUI?: AdditionalPropsType[];
};
export declare type AuditInfo = {
    issueid?: string;
    level?: 'Fatal' | 'Error' | 'Critical' | 'Warning' | 'Info';
    category?: string;
    message?: string;
    type?: string;
    fileName?: string;
    [k: string]: unknown;
    additionalPropsForUI?: AdditionalPropsType[];
};
export declare type ElementInfo = {
    ecinstanceid?: string;
    sourceid?: string;
    [k: string]: unknown;
    additionalPropsForUI?: AdditionalPropsType[];
};
export interface SyncReportOpenedEventDataType {
    syncReportOpenTelemetry?: syncReportOpenTelemetryDataType;
    onSyncReportOpenEventPerform?: () => void;
}
export interface IssueArticleOpenEventDataType {
    issueArticleOpenTelemetry?: issueArticleOpenTelemetryDataType;
    onIssueArticleOpenEventPerform?: (issueId: string) => void;
}
export interface syncReportOpenTelemetryDataType {
    iModelId?: string;
    projectId?: string;
    userEmail?: string;
    runStatus?: string;
    taskStatus?: string;
    connectionId?: string;
    runId?: string;
    reportId?: string;
    isDetailsColumnEnabled?: string;
    consumedApplicationName?: string;
    ultimateId?: string;
    [k: string]: unknown;
    additionalPropsForAppInsights?: AdditionalPropsType[];
}
export interface issueArticleOpenTelemetryDataType {
    iModelId?: string;
    projectId?: string;
    userEmail?: string;
    connectionId?: string;
    runId?: string;
    reportId?: string;
    isDetailsColumnEnabled?: string;
    consumedApplicationName?: string;
    ultimateId?: string;
    [k: string]: unknown;
    additionalPropsForAppInsights?: AdditionalPropsType[];
}
